/**
 * core.js - all global scripts belong in this file.
 */

utils.currentPage = function() {"use strict"
  let curPage = window.location.pathname.substring(
    window.location.pathname.lastIndexOf ('/') + 1
    ).split("?")[0];
  if(!curPage){ curPage = "home" }
  return curPage
};
utils.debounce = function (func,time){
  var timer;
  return function(event){
    if(timer) clearTimeout(timer);
    timer = setTimeout(func,time,event);
  };
}
utils.scrollDistance = function() {
  return document.documentElement.scrollTop;
}
utils.offsetHeight = function() {
  return document.querySelector('#header').offsetHeight;
}
utils.addClass = function( selector, className ) {
  var listItems = document.querySelectorAll(selector);
  for (var i = 0; i < listItems.length; i++) {
    listItems[i].classList.add(className);
  }
}
utils.removeClass = function( selector, className ) {
  var listItems = document.querySelectorAll(selector);
  for (var i = 0; i < listItems.length; i++) {
    listItems[i].classList.remove(className);
  }
}
utils.scrollTo = function( element ) {
  window.scroll({
    behavior: 'smooth',
    left: 0,
    top: (element.getBoundingClientRect().top + window.scrollY) - 140
  });
  //console.log(document.scrollTop, element.getBoundingClientRect().top + window.scrollY);
}

var accordion = {};
accordion.toggle = function (event) {"use strict";
  if( event.target.parentNode.classList.contains('open') ) {
    utils.removeClass('ul.accordion li.open','open');
  } else {
    utils.removeClass('ul.accordion li.open','open');
    event.target.parentNode.classList.add('open');
  }
  // optional scroll functionality
  // utils.scrollTo(event.target.parentNode);
};

var instafeed = {
  init: function() {"use strict";
    document.querySelector("#feed").innerHTML = '<!-- LightWidget WIDGET --><script src="https://cdn.lightwidget.com/widgets/lightwidget.js"></script><iframe src="https://cdn.lightwidget.com/widgets/a1b2582b32265d1f8402721b651fdeff.html" scrolling="no" allowtransparency="true" class="lightwidget-widget" style="width:100%;border:0;overflow:hidden;"></iframe>';
  }
};

var keyartVideo = {}
keyartVideo.init = function(){

  if($('body').hasClass('home')){
    var theVideo = document.querySelector('#keyart video');
  }

  //theVideo.play();
  
  $('.toggle-sound').on('click',function(e){
    e.preventDefault();
    if ( $(this).hasClass('unmuted') ) {
      $(theVideo).prop('muted',true);
      $(this).removeClass('unmuted');
      $(this).addClass('muted');
    } else {
      $(theVideo).prop('muted',false);
      $(this).removeClass('muted');
      $(this).addClass('unmuted');
    }
  });

  setTimeout(function(){
    $('.replay').addClass('active');
  },5000);
  
  $(document).on('click','.replay.active',function(e){
    e.preventDefault();
    console.log(theVideo);
    theVideo.pause();
    theVideo.currentTime = 0;
    theVideo.play();
    $('.replay').removeClass('active');
    setTimeout(function(){
      $('.replay').addClass('active');
    },5000);
  });
}

var optin = {};
optin.forms = document.querySelectorAll('.subscribe');
optin.fields = ["email"]
optin.initializeForms = function() { "use strict";
  function sendAddress(form) {
    var formData = new FormData(form);
    formData.append('ajax', true);

    var xhr = new XMLHttpRequest();
    xhr.open('POST', './_inc/optin_action.php', true);
    xhr.onload = function() {
      if (xhr.status >= 200 && xhr.status < 400) {

        //console.log(xhr.status);
        let response = JSON.parse('[' + xhr.response + ']');
        //console.log(response[0]);
          for(i=0;i<optin.forms.length;i++){
            optin.forms[i].style.display = 'none';
            var parentDiv = optin.forms[i].parentElement;
            if(parentDiv.querySelector('h3:first-child')){
              let thisH3 = parentDiv.querySelector('h3:first-child')
              thisH3.remove();
            }
            var thanksMessage = document.createElement('h3');
            thanksMessage.className = 'text-center form-thanks';
            if (response[0].status == 200){
              thanksMessage.innerHTML = 'THANK YOU FOR <br class="visible-xs" />SIGNING&nbsp;UP.</span>';
            } else if( response[0].status == 400 ) {
            } else {
              if(response[0].detail){
                thanksMessage.innerHTML = response[0].detail;
              } else {
                thanksMessage.innerHTML = "You've been added to&nbsp;the&nbsp;list. Thanks&nbsp;for&nbsp;your subscription.";
              }
            }
            parentDiv.appendChild(thanksMessage);
          }
          dataLayer.push({ 'event': 'signup-successful' });
          optin.submittedSuccessfully = true;
      }
    };
    xhr.send(formData);
  }
  class FormValidator {
    constructor(form, fields) {
      this.form = form
      this.fields = fields
    }
    initialize() {
      this.validateOnSubmit()
    }
    validateOnSubmit() {
      let self = this
      var first_submit = true;
      this.form.addEventListener('submit', e => {
        e.preventDefault()
        self.fields.forEach(field => {
          const inputSelector = "#"+self.form.id+"-"+field;
          const input = document.querySelector(inputSelector)
          self.validateFields(input,true)
          if( first_submit ) {
            self.validateOnEntry()
            first_submit = false;
          }
        })
      })
    }
    validateOnEntry() {
      let self = this
      this.fields.forEach(field => {
        const inputSelector = "#"+self.form.id+"-"+field;
        const input = document.querySelector(inputSelector)
        input.addEventListener('input', event => {
          self.validateFields(input,false)
        })
      })
    }
    validateFields(field,isSubmit) {
      // Check presence of values
      if (field.value.trim() === "") {
        this.setStatus(field, field.id+" cannot be blank", "error")
      } else {
        this.setStatus(field, null, "success")
      }
      let handled = false;
      // check for a valid email address
      if (field.type === "email") {
        const re = /\S+@\S+\.\S+/
        if (re.test(field.value)) {
          this.setStatus(field, null, "success")
          if(isSubmit && !handled){
            sendAddress(this.form);
            handled = true;
          }
        } else {
          this.setStatus(field, "Please enter valid email address", "error")
        }
      }
    }
    setStatus(field, message, status) {
      let thisField = field.parentElement;
      let thisErr = thisField.querySelector('.error-message')
      if (status === "success") {
        thisField.classList.remove('error')
        if(thisErr){
          thisErr.innerHTML = '';
        }
      }
      if (status === "error") {
        thisField.classList.add('error')
        if(thisErr){
          thisErr.innerHTML = message;
        }
      }
    }
  }
  for(var i=0;i < optin.forms.length;i++){
    optin.forms[i].id = "form"+i;
    const validator = new FormValidator(optin.forms[i], optin.fields)
    validator.initialize()
    for(var j=0;j < optin.fields.length;j++){
      let thisField = optin.forms[i].querySelector("input");
      thisField.id = "form"+i+"-"+optin.fields[j];
    }
  }
}
optin.upCount = 0;
optin.rightCount = 0;
optin.prevY = 0;
optin.prevX = 0;
optin.exitPopupOpen = false;
optin.exitPopupInitialized = false;
optin.submittedSuccessfully = false;
optin.exitPopup = function(e) {"use strict";
  optin.exitPopupOpen = true;
  //document.documentElement.classList.add('exit-popup-open');
  if(!optin.exitPopupinitialized) {
    optin.exitPopupInitialized = true;
  }
};

// NAMESPACE FOR MAIN MENU FUNCTIONS
var nav = {}
nav.toggle = function(e) {
    // if menu is open, close it up
    if(document.documentElement.classList.contains('menu-open')){
      // but only if no sub categories
      if(!e.target.classList.contains('top-level') && !e.target.classList.contains('arrow')){
        setTimeout(function(){
          document.documentElement.classList.remove('menu-open');
          document.getElementById("nav-close").id = "nav-open";
          document.getElementById("nav-open").setAttribute('aria-label', 'open main menu');
          document.getElementById("nav-open").setAttribute('aria-expanded', false);
        }, 100);
        return true;
      }
    // if menu is closed, open it
    } else {
      document.documentElement.classList.add('menu-open');
      document.getElementById("nav-open").id = "nav-close";
      document.getElementById("nav-close").setAttribute('aria-label', 'close main menu');
      document.getElementById("nav-close").setAttribute('aria-expanded', true);
      return true;
    }
}

// NAMESPACE FOR CLICK FUNCTIONS
var clickHandler = {}
clickHandler.init = function() {"use strict";
  var el = document.querySelector(utils.currentPage());
  if(el){
    el.scrollIntoView({
      behavior: 'smooth' // smooth scroll
    })
  }
  // click handler
  var handled = false;
  function handleClick(e) {
    if(!handled){
      handled = true;
      setTimeout(function(){ handled=false },200);
      // main menu
      if( e.target.classList.contains('nav-toggle') || e.target.id == 'main-menu' ){
        nav.toggle(e);
      }
      // video thumbnail
      if(e.target.classList.contains('video-link')){
        e.preventDefault();
        document.querySelector('.overlay-inner').innerHTML = '<div class="video-container"><iframe src="https://www.youtube.com/embed/'+ e.target.dataset.id +'?rel=0&modestbranding=1&autohide=1&showinfo=0&autoplay=1" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe></div>';
        document.documentElement.classList.add('overlay-open');
      }
      // accordion
      else if(e.target.parentNode.parentNode.classList.contains('accordion')){
        accordion.toggle(e);
        //console.log(e.target.innerHTML);
      }
      // overlay close
      if(e.target.classList.contains('close')){
        document.documentElement.classList.remove('exit-popup-open');
        document.documentElement.classList.remove('overlay-open');
        //console.log(utils.currentPage());
        if(utils.currentPage() != 'photos' ){
          document.querySelector('.overlay-inner').innerHTML = '';
        }
        optin.exitPopupOpen = false;
      }
      // listen button
      if(e.target.id == 'btn-listen'){
        spotify.init();
      }
    } else {
      return false;
    }
  }
  window.addEventListener('touchend', handleClick, Modernizr.passiveeventlisteners ? {passive: true} : false);
  window.addEventListener('click', handleClick, false);
};

var scrollHandler = {}
scrollHandler.init = function(){ "use strict"
  var firstScroll = true;
  // handles scroll events for the page
  function handleScroll(e) {
    // first scroll
    if(firstScroll){
      if( document.body.classList.contains('home') ){
        instafeed.init();
      }
      firstScroll = false;
    }
    // parallax
    if(document.querySelector('.parallax-image')){
      //const parallaxImage = document.querySelector('.parallax-image');
      //const offsetY = utils.scrollDistance() / 3.7; // Adjust the factor for the parallax effect
      //parallaxImage.style.transform = `translate3d(0, ${offsetY}px, 0)`;
    }
    if(document.body.classList.contains('home')){
      if(document.documentElement.classList.contains('touch') && !optin.submittedSuccessfully){
        if(!document.body.classList.contains('touch') && !optin.submittedSuccessfully){
          let scrollDist = utils.scrollDistance();
          //console.log(scrollDist);
          optin.upCount = (scrollDist <= optin.prevSD) ? optin.upCount+1 : 0;
          if((optin.upCount >= 16) && !optin.exitPopupInitialized && !document.body.classList.contains('menu-open')) {
            optin.exitPopup(e);
          }
          optin.prevSD = scrollDist;
        }
      }
    }
  }
  window.addEventListener("scroll", utils.debounce(function(e){
    handleScroll(e);
  },10));
};

var mouseMoveHandler = {}
mouseMoveHandler.init = function(){ "use strict"
  // handles scroll events for the page
  function handleMouseMove(e) {
    if(!document.documentElement.classList.contains('touch') && !optin.submittedSuccessfully){
      let x = e.clientX;
      let y = e.clientY;
      optin.upCount = (y <= optin.prevY) ? optin.upCount+1 : 0;
      optin.rightCount = (x > optin.prevX) ? optin.rightCount+1 : 0;
      if((optin.upCount >= 12) && (y < 200) && (x > 200) && (x < window.innerWidth - 240) && !optin.exitPopupInitialized && !document.documentElement.classList.contains('menu-open')) {
        optin.exitPopup(e);
      }
      optin.prevY = y;
      optin.prevX = x;
      //console.log(optin.upCount, optin.rightCount, optin.prevX, optin.prevY);
      //console.log('x='+x+', y='+y);
    }
  }
  window.addEventListener("mousemove", utils.debounce(function(e){
    handleMouseMove(e)
  },7));
};
/*
var popstateHandler = {}
popstateHandler.init = function(){ "use strict"
  // handles scroll events for the page
  function handlePopstate(e) {
    if(!optin.submittedSuccessfully && document.body.classList.contains('touch')){
      optin.exitPopup(e);
    }
  }
  window.addEventListener("popstate", utils.debounce(function(e){
    handlePopstate(e)
  },7));
};*/


// NAMESPACE FOR ROTATOR
var rotator = {};
rotator.rotate = function (selector) { "use strict";
  var thisTimeout;
  var thisSlide = document.querySelector(selector);
  console.log(thisSlide);
  var thisTime = thisSlide.parentElement.dataset.time;
  thisTime = ( thisTime ) ? thisTime : 5000;
  var numberOfSlides = document.querySelectorAll(selector).length;
  var currentSlide = 0;
  var prevSlide = 0;
  var nextSlide = 0;
  function rotateSlide(slideNum) {
    if ( slideNum != undefined ) {
      currentSlide =  slideNum;
    } else{
      currentSlide++;
    }
    //console.log(currentSlide);
    if( currentSlide > numberOfSlides ){ currentSlide = 1; }
    prevSlide = currentSlide - 1;
    nextSlide = currentSlide + 1;
    if( prevSlide < 1 ){ prevSlide = numberOfSlides; }
    if( nextSlide > numberOfSlides ){ nextSlide = 1; }
    const slides = document.querySelectorAll(selector);
    if( slides ){ slides.forEach((slide) => {
        slide.classList.remove('active', 'next', 'prev', 'current');
      }); }

    //console.log(document.querySelector(selector + ":nth-child("+currentSlide+")"));
    document.querySelector(selector + ":nth-child("+currentSlide+")").classList.add('active', 'current');
    if (thisSlide.parentElement.classList.contains("slide")){
      document.querySelector(selector + ":nth-child("+prevSlide+")").classList.add('active', 'prev');
      document.querySelector(selector + ":nth-child("+nextSlide+")").classList.add('active', 'next');
    }
    if (thisSlide.parentElement.classList.contains("autoplay")){
      if(thisTimeout){clearTimeout(thisTimeout);}
      thisTimeout = setTimeout( rotateSlide, thisTime );
    }
  }
  if (thisSlide.parentElement.classList.contains("autoplay")){
    rotateSlide();
  }
  
  var container = thisSlide.parentNode.parentNode;
  var handled = false;

  function handleInteraction(e) {
    if(!handled){
      handled = true;
      setTimeout(function(){
        handled=false;
      },200);
      //console.log('interacted')
      if(e.target.classList.contains('dot')){
        let selectedSlide = [...e.target.parentNode.children].indexOf(e.target)
        selectedSlide++
        //console.log(selectedSlide)
        currentSlide = selectedSlide
        rotateSlide()
      } else if(e.target.classList.contains('next')){
        let selectedSlide = currentSlide
        //console.log(selectedSlide)
        currentSlide = selectedSlide
        rotateSlide()
      } else if(e.target.classList.contains('prev')){
        //console.log(currentSlide)
        let selectedSlide = currentSlide
        selectedSlide = currentSlide - 2;
        if(selectedSlide == -1){selectedSlide = numberOfSlides-1}
        if(selectedSlide == 0){selectedSlide = numberOfSlides}
        currentSlide = selectedSlide
        rotateSlide()
      } else if(e.target.classList.contains('photo-button')){
        //console.log(e.target.dataset.number)
        let selectedSlide = e.target.dataset.number;
        currentSlide = selectedSlide
        rotateSlide()
        document.documentElement.classList.add('overlay-open');
      }
    }
  }
  window.addEventListener('touchend', handleInteraction, Modernizr.passiveeventlisteners ? {passive: true} : false)
  window.addEventListener('click', handleInteraction)
};

var video = {}
video.play = function(videoSelector) {
  let thisVideo = document.querySelector(videoSelector);
  thisVideo.classList.remove('custom-thumb');
  thisVideo.innerHTML = '<iframe width="560" height="315" src="https://www.youtube.com/embed/'+ thisVideo.dataset.id +'?autoplay=1" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>';
}
video.init = function(){ "use strict"  
  if( utils.isTouchEnabled ) {
    document.querySelector("#video-play.custom-thumb").click;
  }
};

var spotify = {}
spotify.init = function(){ "use strict"
  let spotify = document.getElementById('spotify');
  spotify.querySelector('.container').innerHTML = '<iframe style="border-radius:12px" src="https://open.spotify.com/embed/album/22UlcdIxtmapTzhh6koX1o?utm_source=generator" width="100%" height="352" frameBorder="0" allowfullscreen="" allow="autoplay; clipboard-write; encrypted-media; fullscreen; picture-in-picture" loading="lazy"></iframe>';
  if(spotify.classList.contains('open')) {
    spotify.classList.remove('open');
  } else {
    spotify.classList.add('open');
  }
};

window.addEventListener("load", (event) => {
  //console.log("page is fully loaded");
});

// jQuery Namespace
$ (document).ready (function () {"use strict";
  //console.log("document ready");
  $('html').addClass('page-loaded');
  clickHandler.init();
  scrollHandler.init();
  
  if (document.body.classList.contains('home')) {
    //mouseMoveHandler.init();
    keyartVideo.init();
  }
  if (document.body.classList.contains('opening-night')) {
    video.init();
  }
  
/* beginning of auto-initialize for Rotator script
  var rotators = document.querySelectorAll('.rotator');
  for (var i=0; i < rotators.length; i++) {
    //rotators[i].querySelector(':first-child');
    //console.log(rotators[i].querySelector(':first-child'));
  }
  */

  if (document.body.classList.contains('signup')) {
    rotator.rotate("#quote-rotator .quote");
  }
  if (document.body.classList.contains('home')) {
    //rotator.rotate("#quotes .quote");
    rotator.rotate("span.cat > span");
  }
  if (document.querySelector("ul.rotator li")) {
    rotator.rotate("ul.rotator li");
  }
});